#test of data_ptr
#make unique instance of ruby for c++ pointer
#and cast c++ pointer to the ruby object
require "qte"
include Qte

module CPPPtr

  @@PTRObjectMap = {}

def initialize (*arg)
  super (*arg)
  @@PTRObjectMap[self.to_data_ptr]=self
  sclass =  self.class
  if(!sclass.respond_to? "fromPtr")
    eval("def #{sclass}.fromPtr p;
    #p @@PTRObjectMap;
    result=@@PTRObjectMap[p.to_data_ptr];
    (result.class == self) ? result : nil;
    end")
  end
end

end

class MyQObject < QObject

include CPPPtr

def initialize myid=0
  super()
  @myid = myid
  print "initialized myid = #{myid}\n"
end



def myid
  @myid
end

end

class MyMyQObject < QObject

include CPPPtr
def initialize
  super
end
end


mq1 = MyQObject.new 1 
mmq1 = MyMyQObject.new 
p mq1;print "mq1\n"
p mmq1;print "mmq1\n"

ol = QObjectList.new

ol.insert(0,mq1)
ol.insert(1,mmq1)

q1 = ol.at 0
qq1 = ol.at 1

p q1;print "q1\n"
p mq1;print "mq1\n"
p MyQObject.fromPtr(q1)

p qq1;print "qq1\n"
p mmq1;print "mmq1\n"
p MyMyQObject.fromPtr(qq1)
print "error\n"
p MyMyQObject.fromPtr(q1)


